==> create-fly-1.21.8-6.0.8-1-sources.jar: com/zurrtum/create/client/content/equipment/extendoGrip/ExtendoGripRenderHandler.java <==
package com.zurrtum.create.client.content.equipment.extendoGrip;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import net.minecraft.class_1007;
import net.minecraft.class_10439;
import net.minecraft.class_10444;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1664;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_746;
import net.minecraft.class_811;
import net.minecraft.class_898;
import net.minecraft.class_9334;

public class ExtendoGripRenderHandler {

    public static float mainHandAnimation;
    public static float lastMainHandAnimation;
    public static boolean holding;
    private static final class_10444 state = new class_10444();

    public static void tick(class_310 mc) {
        lastMainHandAnimation = mainHandAnimation;
        mainHandAnimation *= class_3532.method_15363(mainHandAnimation, 0.8f, 0.99f);

        holding = false;
        if (!getRenderedOffHandStack(mc).method_31574(AllItems.EXTENDO_GRIP))
            return;
        class_1799 main = getRenderedMainHandStack(mc);
        if (main.method_7960())
            return;
        if (!(main.method_7909() instanceof class_1747))
            return;
        mc.method_65386().method_65598(state, main, class_811.field_4322, null, null, 0);
        if (!state.method_65608())
            return;
        holding = true;
    }

    public static boolean onRenderPlayerHand(
        class_1799 heldItem,
        class_310 mc,
        class_898 entityRenderDispatcher,
        class_4587 ms,
        class_4597 buffer,
        int light,
        class_1268 hand,
        float equipProgress,
        float swingProgress
    ) {
        class_1799 offhandItem = getRenderedOffHandStack(mc);
        boolean inOffhand = offhandItem.method_31574(AllItems.EXTENDO_GRIP);
        boolean inHeldItem = heldItem.method_31574(AllItems.EXTENDO_GRIP);
        if (!inOffhand && !inHeldItem)
            return false;
        class_746 player = mc.field_1724;
        boolean rightHand = hand == class_1268.field_5808 ^ player.method_6068() == class_1306.field_6182;

        var msr = TransformStack.of(ms);
        float flip = rightHand ? 1.0F : -1.0F;
        boolean blockItem = heldItem.method_7909() instanceof class_1747;
        equipProgress = blockItem ? 0 : equipProgress / 4;

        ms.method_22903();
        if (hand == class_1268.field_5808) {
            if (1 - swingProgress > mainHandAnimation && swingProgress > 0 && swingProgress < 0.1)
                mainHandAnimation = 0.95f;

            ms.method_46416(flip * (0.64000005F - .1f), -0.4F + equipProgress * -0.6F, -0.71999997F + .3f);

            ms.method_22903();
            msr.rotateYDegrees(flip * 75.0F);
            ms.method_46416(flip * -1.0F, 3.6F, 3.5F);
            msr.rotateZDegrees(flip * 120).rotateXDegrees(200).rotateYDegrees(flip * -135.0F);
            ms.method_46416(flip * 5.6F, 0.0F, 0.0F);
            msr.rotateYDegrees(flip * 40.0F);
            ms.method_46416(flip * 0.05f, -0.3f, -0.3f);

            class_1007 playerrenderer = (class_1007) entityRenderDispatcher.method_3953(player);
            class_2960 texture = player.method_52814().comp_1626();
            if (rightHand)
                playerrenderer.method_4220(ms, buffer, light, texture, player.method_7348(class_1664.field_7570));
            else
                playerrenderer.method_4221(ms, buffer, light, texture, player.method_7348(class_1664.field_7568));
            ms.method_22909();

            // Render gun
            ms.method_22903();
            ms.method_46416(flip * -0.1f, 0, -0.3f);
            state.method_65605();
            state.field_55337 = rightHand ? class_811.field_4322 : class_811.field_4321;
            class_10439 model = mc.method_1554().method_65746((inOffhand ? offhandItem : heldItem).method_58694(class_9334.field_54199));
            model.method_65584(state, inHeldItem && inOffhand ? null : heldItem, mc.method_65386(), state.field_55337, mc.field_1687, player, 0);
            state.method_65604(ms, buffer, light, class_4608.field_21444);
            ms.method_22909();
        }
        ms.method_22909();
        return true;
    }

    private static class_1799 getRenderedMainHandStack(class_310 mc) {
        return mc.method_1561().method_43336().field_4047;
    }

    private static class_1799 getRenderedOffHandStack(class_310 mc) {
        return mc.method_1561().method_43336().field_4048;
    }

}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/content/equipment/extendoGrip/ExtendoGripRenderHandler.java <==
package com.zurrtum.create.client.content.equipment.extendoGrip;

import com.zurrtum.create.AllItems;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import net.minecraft.class_1007;
import net.minecraft.class_10439;
import net.minecraft.class_10444;
import net.minecraft.class_11659;
import net.minecraft.class_1268;
import net.minecraft.class_1306;
import net.minecraft.class_1664;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4608;
import net.minecraft.class_742;
import net.minecraft.class_746;
import net.minecraft.class_811;
import net.minecraft.class_898;
import net.minecraft.class_9334;

public class ExtendoGripRenderHandler {

    public static float mainHandAnimation;
    public static float lastMainHandAnimation;
    public static boolean holding;
    private static final class_10444 state = new class_10444();

    public static void tick(class_310 mc) {
        lastMainHandAnimation = mainHandAnimation;
        mainHandAnimation *= class_3532.method_15363(mainHandAnimation, 0.8f, 0.99f);

        holding = false;
        if (!getRenderedOffHandStack(mc).method_31574(AllItems.EXTENDO_GRIP))
            return;
        class_1799 main = getRenderedMainHandStack(mc);
        if (main.method_7960())
            return;
        if (!(main.method_7909() instanceof class_1747))
            return;
        mc.method_65386().method_65598(state, main, class_811.field_4322, null, null, 0);
        if (!state.method_65608())
            return;
        holding = true;
    }

    public static boolean onRenderPlayerHand(
        class_1799 heldItem,
        class_310 mc,
        class_898 entityRenderDispatcher,
        class_4587 ms,
        class_11659 queue,
        int light,
        class_1268 hand,
        float equipProgress,
        float swingProgress
    ) {
        class_1799 offhandItem = getRenderedOffHandStack(mc);
        boolean inOffhand = offhandItem.method_31574(AllItems.EXTENDO_GRIP);
        boolean inHeldItem = heldItem.method_31574(AllItems.EXTENDO_GRIP);
        if (!inOffhand && !inHeldItem)
            return false;
        class_746 player = mc.field_1724;
        boolean rightHand = hand == class_1268.field_5808 ^ player.method_6068() == class_1306.field_6182;

        var msr = TransformStack.of(ms);
        float flip = rightHand ? 1.0F : -1.0F;
        boolean blockItem = heldItem.method_7909() instanceof class_1747;
        equipProgress = blockItem ? 0 : equipProgress / 4;

        ms.method_22903();
        if (hand == class_1268.field_5808) {
            if (1 - swingProgress > mainHandAnimation && swingProgress > 0 && swingProgress < 0.1)
                mainHandAnimation = 0.95f;

            ms.method_46416(flip * (0.64000005F - .1f), -0.4F + equipProgress * -0.6F, -0.71999997F + .3f);

            ms.method_22903();
            msr.rotateYDegrees(flip * 75.0F);
            ms.method_46416(flip * -1.0F, 3.6F, 3.5F);
            msr.rotateZDegrees(flip * 120).rotateXDegrees(200).rotateYDegrees(flip * -135.0F);
            ms.method_46416(flip * 5.6F, 0.0F, 0.0F);
            msr.rotateYDegrees(flip * 40.0F);
            ms.method_46416(flip * 0.05f, -0.3f, -0.3f);

            class_1007<class_742> playerrenderer = entityRenderDispatcher.method_74405(player);
            class_2960 texture = player.method_52814().comp_1626().comp_3627();
            if (rightHand)
                playerrenderer.method_4220(ms, queue, light, texture, player.method_74091(class_1664.field_7570));
            else
                playerrenderer.method_4221(ms, queue, light, texture, player.method_74091(class_1664.field_7568));
            ms.method_22909();

            // Render gun
            ms.method_22903();
            ms.method_46416(flip * -0.1f, 0, -0.3f);
            state.method_65605();
            state.field_55337 = rightHand ? class_811.field_4322 : class_811.field_4321;
            class_10439 model = mc.method_1554().method_65746((inOffhand ? offhandItem : heldItem).method_58694(class_9334.field_54199));
            model.method_65584(state, inHeldItem && inOffhand ? null : heldItem, mc.method_65386(), state.field_55337, mc.field_1687, player, 0);
            state.method_65604(ms, queue, light, class_4608.field_21444, 0);
            ms.method_22909();
        }
        ms.method_22909();
        return true;
    }

    private static class_1799 getRenderedMainHandStack(class_310 mc) {
        return mc.method_1561().method_43336().field_4047;
    }

    private static class_1799 getRenderedOffHandStack(class_310 mc) {
        return mc.method_1561().method_43336().field_4048;
    }

}
